==> smartdoc-1.0.0.20020826.zip: src/jp/gr/java_conf/jaba2/xml/relax/cooked/CData.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2002  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.xml.relax.cooked;

import java.util.*;
import org.w3c.dom.*;
import jp.gr.java_conf.jaba2.datatype.XMLFacet;
import jp.gr.java_conf.jaba2.xml.datatype.*;
import jp.gr.java_conf.jaba2.xml.relax.raw.RElement;
import jp.gr.java_conf.jaba2.xml.relax.raw.RAttribute;

/**
 * CData
 *
 * @since   Apr. 18, 2002
 * @version Jun. 29, 2002
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class CData extends CNode implements ICPatternContent, ICParticle {
    private Datatype datatype_;

    public CData(String xmlType, CModule module) {
	datatype_ = module.makeDatatype(xmlType);
    }

    public CData(String xmlType, XMLFacet[] facets, CModule module) {
	if (facets != null) {
	    datatype_ = module.makeDatatype(xmlType, facets);
	} else {
	    datatype_ = module.makeDatatype(xmlType);
	}
    }

    public final Datatype getDatatype() {
	return (datatype_);
    }
}

==> smartdoc-1.0.0.20031106.zip: src/jp/gr/java_conf/jaba2/xml/relax/cooked/CData.java <==
/*
 * The JabaJaba class library
 *  Copyright (C) 1997-2003  ASAMI, Tomoharu (asami@AsamiOffice.com)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

package jp.gr.java_conf.jaba2.xml.relax.cooked;

import java.util.*;
import org.w3c.dom.*;
import jp.gr.java_conf.jaba2.datatype.XMLFacet;
import jp.gr.java_conf.jaba2.xml.datatype.*;
import jp.gr.java_conf.jaba2.xml.relax.raw.RElement;
import jp.gr.java_conf.jaba2.xml.relax.raw.RAttribute;

/**
 * CData
 *
 * @since   Apr. 18, 2002
 * @version Sep. 14, 2003
 * @author  ASAMI, Tomoharu (asami@AsamiOffice.com)
 */
public class CData extends CNode implements ICPatternContent, ICParticle {
    private Datatype datatype_;

    public CData(String xmlType, CModule module) {
	datatype_ = module.makeDatatype(xmlType);
    }

    public CData(
        String xmlType,
        XMLFacet[] facets,
        Element xmlElement,
        CModule module
    ) {
	if (facets != null) {
	    datatype_ = module.makeDatatype(xmlType, facets);
	} else {
	    datatype_ = module.makeDatatype(xmlType);
	}
        datatype_.setXmlElement(xmlElement);
    }

    public CData(CData data) {
        datatype_ = data.datatype_;
    }

    public final Datatype getDatatype() {
	return (datatype_);
    }
}
